==> openshift-model-config-6.8.0-sources.jar: io/fabric8/openshift/api/model/config/v1/OpenIDIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.List;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OpenIDIdentityProviderFluent<A extends OpenIDIdentityProviderFluent<A>> extends BaseFluent<A>{
  public OpenIDIdentityProviderFluent() {
  }
  public OpenIDIdentityProviderFluent(OpenIDIdentityProvider instance) {
    instance = (instance != null ? instance : new OpenIDIdentityProvider());

    if (instance != null) {
      this.withCa(instance.getCa());
      this.withClaims(instance.getClaims());
      this.withClientID(instance.getClientID());
      this.withClientSecret(instance.getClientSecret());
      this.withExtraAuthorizeParameters(instance.getExtraAuthorizeParameters());
      this.withExtraScopes(instance.getExtraScopes());
      this.withIssuer(instance.getIssuer());
      this.withCa(instance.getCa());
      this.withClaims(instance.getClaims());
      this.withClientID(instance.getClientID());
      this.withClientSecret(instance.getClientSecret());
      this.withExtraAuthorizeParameters(instance.getExtraAuthorizeParameters());
      this.withExtraScopes(instance.getExtraScopes());
      this.withIssuer(instance.getIssuer());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ConfigMapNameReferenceBuilder ca;
  private OpenIDClaimsBuilder claims;
  private String clientID;
  private SecretNameReferenceBuilder clientSecret;
  private Map<String,String> extraAuthorizeParameters;
  private List<String> extraScopes = new ArrayList<String>();
  private String issuer;
  private Map<String,Object> additionalProperties;
  public ConfigMapNameReference buildCa() {
    return this.ca!=null ?this.ca.build():null;
  }
  public A withCa(ConfigMapNameReference ca) {
    _visitables.get("ca").remove(this.ca);
    if (ca!=null){ this.ca= new ConfigMapNameReferenceBuilder(ca); _visitables.get("ca").add(this.ca);} else { this.ca = null; _visitables.get("ca").remove(this.ca); } return (A) this;
  }
  public boolean hasCa() {
    return this.ca != null;
  }
  public A withNewCa(String name) {
    return (A)withCa(new ConfigMapNameReference(name));
  }
  public CaNested<A> withNewCa() {
    return new CaNested(null);
  }
  public CaNested<A> withNewCaLike(ConfigMapNameReference item) {
    return new CaNested(item);
  }
  public CaNested<A> editCa() {
    return withNewCaLike(java.util.Optional.ofNullable(buildCa()).orElse(null));
  }
  public CaNested<A> editOrNewCa() {
    return withNewCaLike(java.util.Optional.ofNullable(buildCa()).orElse(new ConfigMapNameReferenceBuilder().build()));
  }
  public CaNested<A> editOrNewCaLike(ConfigMapNameReference item) {
    return withNewCaLike(java.util.Optional.ofNullable(buildCa()).orElse(item));
  }
  public OpenIDClaims buildClaims() {
    return this.claims!=null ?this.claims.build():null;
  }
  public A withClaims(OpenIDClaims claims) {
    _visitables.get("claims").remove(this.claims);
    if (claims!=null){ this.claims= new OpenIDClaimsBuilder(claims); _visitables.get("claims").add(this.claims);} else { this.claims = null; _visitables.get("claims").remove(this.claims); } return (A) this;
  }
  public boolean hasClaims() {
    return this.claims != null;
  }
  public ClaimsNested<A> withNewClaims() {
    return new ClaimsNested(null);
  }
  public ClaimsNested<A> withNewClaimsLike(OpenIDClaims item) {
    return new ClaimsNested(item);
  }
  public ClaimsNested<A> editClaims() {
    return withNewClaimsLike(java.util.Optional.ofNullable(buildClaims()).orElse(null));
  }
  public ClaimsNested<A> editOrNewClaims() {
    return withNewClaimsLike(java.util.Optional.ofNullable(buildClaims()).orElse(new OpenIDClaimsBuilder().build()));
  }
  public ClaimsNested<A> editOrNewClaimsLike(OpenIDClaims item) {
    return withNewClaimsLike(java.util.Optional.ofNullable(buildClaims()).orElse(item));
  }
  public String getClientID() {
    return this.clientID;
  }
  public A withClientID(String clientID) {
    this.clientID=clientID; return (A) this;
  }
  public boolean hasClientID() {
    return this.clientID != null;
  }
  public SecretNameReference buildClientSecret() {
    return this.clientSecret!=null ?this.clientSecret.build():null;
  }
  public A withClientSecret(SecretNameReference clientSecret) {
    _visitables.get("clientSecret").remove(this.clientSecret);
    if (clientSecret!=null){ this.clientSecret= new SecretNameReferenceBuilder(clientSecret); _visitables.get("clientSecret").add(this.clientSecret);} else { this.clientSecret = null; _visitables.get("clientSecret").remove(this.clientSecret); } return (A) this;
  }
  public boolean hasClientSecret() {
    return this.clientSecret != null;
  }
  public A withNewClientSecret(String name) {
    return (A)withClientSecret(new SecretNameReference(name));
  }
  public ClientSecretNested<A> withNewClientSecret() {
    return new ClientSecretNested(null);
  }
  public ClientSecretNested<A> withNewClientSecretLike(SecretNameReference item) {
    return new ClientSecretNested(item);
  }
  public ClientSecretNested<A> editClientSecret() {
    return withNewClientSecretLike(java.util.Optional.ofNullable(buildClientSecret()).orElse(null));
  }
  public ClientSecretNested<A> editOrNewClientSecret() {
    return withNewClientSecretLike(java.util.Optional.ofNullable(buildClientSecret()).orElse(new SecretNameReferenceBuilder().build()));
  }
  public ClientSecretNested<A> editOrNewClientSecretLike(SecretNameReference item) {
    return withNewClientSecretLike(java.util.Optional.ofNullable(buildClientSecret()).orElse(item));
  }
  public A addToExtraAuthorizeParameters(String key,String value) {
    if(this.extraAuthorizeParameters == null && key != null && value != null) { this.extraAuthorizeParameters = new LinkedHashMap(); }
    if(key != null && value != null) {this.extraAuthorizeParameters.put(key, value);} return (A)this;
  }
  public A addToExtraAuthorizeParameters(Map<String,String> map) {
    if(this.extraAuthorizeParameters == null && map != null) { this.extraAuthorizeParameters = new LinkedHashMap(); }
    if(map != null) { this.extraAuthorizeParameters.putAll(map);} return (A)this;
  }
  public A removeFromExtraAuthorizeParameters(String key) {
    if(this.extraAuthorizeParameters == null) { return (A) this; }
    if(key != null && this.extraAuthorizeParameters != null) {this.extraAuthorizeParameters.remove(key);} return (A)this;
  }
  public A removeFromExtraAuthorizeParameters(Map<String,String> map) {
    if(this.extraAuthorizeParameters == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.extraAuthorizeParameters != null){this.extraAuthorizeParameters.remove(key);}}} return (A)this;
  }
  public Map<String,String> getExtraAuthorizeParameters() {
    return this.extraAuthorizeParameters;
  }
  public <K,V>A withExtraAuthorizeParameters(Map<String,String> extraAuthorizeParameters) {
    if (extraAuthorizeParameters == null) { this.extraAuthorizeParameters =  null;} else {this.extraAuthorizeParameters = new LinkedHashMap(extraAuthorizeParameters);} return (A) this;
  }
  public boolean hasExtraAuthorizeParameters() {
    return this.extraAuthorizeParameters != null;
  }
  public A addToExtraScopes(int index,String item) {
    if (this.extraScopes == null) {this.extraScopes = new ArrayList<String>();}
    this.extraScopes.add(index, item);
    return (A)this;
  }
  public A setToExtraScopes(int index,String item) {
    if (this.extraScopes == null) {this.extraScopes = new ArrayList<String>();}
    this.extraScopes.set(index, item); return (A)this;
  }
  public A addToExtraScopes(java.lang.String... items) {
    if (this.extraScopes == null) {this.extraScopes = new ArrayList<String>();}
    for (String item : items) {this.extraScopes.add(item);} return (A)this;
  }
  public A addAllToExtraScopes(Collection<String> items) {
    if (this.extraScopes == null) {this.extraScopes = new ArrayList<String>();}
    for (String item : items) {this.extraScopes.add(item);} return (A)this;
  }
  public A removeFromExtraScopes(java.lang.String... items) {
    if (this.extraScopes == null) return (A)this;
    for (String item : items) { this.extraScopes.remove(item);} return (A)this;
  }
  public A removeAllFromExtraScopes(Collection<String> items) {
    if (this.extraScopes == null) return (A)this;
    for (String item : items) { this.extraScopes.remove(item);} return (A)this;
  }
  public List<String> getExtraScopes() {
    return this.extraScopes;
  }
  public String getExtraScope(int index) {
    return this.extraScopes.get(index);
  }
  public String getFirstExtraScope() {
    return this.extraScopes.get(0);
  }
  public String getLastExtraScope() {
    return this.extraScopes.get(extraScopes.size() - 1);
  }
  public String getMatchingExtraScope(Predicate<String> predicate) {
    for (String item: extraScopes) { if(predicate.test(item)){ return item;} } return null;
  }
  public boolean hasMatchingExtraScope(Predicate<String> predicate) {
    for (String item: extraScopes) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withExtraScopes(List<String> extraScopes) {
    if (extraScopes != null) {this.extraScopes = new ArrayList(); for (String item : extraScopes){this.addToExtraScopes(item);}} else { this.extraScopes = null;} return (A) this;
  }
  public A withExtraScopes(java.lang.String... extraScopes) {
    if (this.extraScopes != null) {this.extraScopes.clear(); _visitables.remove("extraScopes"); }
    if (extraScopes != null) {for (String item :extraScopes){ this.addToExtraScopes(item);}} return (A) this;
  }
  public boolean hasExtraScopes() {
    return extraScopes != null && !extraScopes.isEmpty();
  }
  public String getIssuer() {
    return this.issuer;
  }
  public A withIssuer(String issuer) {
    this.issuer=issuer; return (A) this;
  }
  public boolean hasIssuer() {
    return this.issuer != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OpenIDIdentityProviderFluent that = (OpenIDIdentityProviderFluent) o;
    if (!java.util.Objects.equals(ca, that.ca)) return false;

    if (!java.util.Objects.equals(claims, that.claims)) return false;

    if (!java.util.Objects.equals(clientID, that.clientID)) return false;

    if (!java.util.Objects.equals(clientSecret, that.clientSecret)) return false;

    if (!java.util.Objects.equals(extraAuthorizeParameters, that.extraAuthorizeParameters)) return false;

    if (!java.util.Objects.equals(extraScopes, that.extraScopes)) return false;

    if (!java.util.Objects.equals(issuer, that.issuer)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ca,  claims,  clientID,  clientSecret,  extraAuthorizeParameters,  extraScopes,  issuer,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ca != null) { sb.append("ca:"); sb.append(ca + ","); }
    if (claims != null) { sb.append("claims:"); sb.append(claims + ","); }
    if (clientID != null) { sb.append("clientID:"); sb.append(clientID + ","); }
    if (clientSecret != null) { sb.append("clientSecret:"); sb.append(clientSecret + ","); }
    if (extraAuthorizeParameters != null && !extraAuthorizeParameters.isEmpty()) { sb.append("extraAuthorizeParameters:"); sb.append(extraAuthorizeParameters + ","); }
    if (extraScopes != null && !extraScopes.isEmpty()) { sb.append("extraScopes:"); sb.append(extraScopes + ","); }
    if (issuer != null) { sb.append("issuer:"); sb.append(issuer + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class CaNested<N> extends ConfigMapNameReferenceFluent<CaNested<N>> implements Nested<N>{
    CaNested(ConfigMapNameReference item) {
      this.builder = new ConfigMapNameReferenceBuilder(this, item);
    }
    ConfigMapNameReferenceBuilder builder;
    public N and() {
      return (N) OpenIDIdentityProviderFluent.this.withCa(builder.build());
    }
    public N endCa() {
      return and();
    }
    
  }
  public class ClaimsNested<N> extends OpenIDClaimsFluent<ClaimsNested<N>> implements Nested<N>{
    ClaimsNested(OpenIDClaims item) {
      this.builder = new OpenIDClaimsBuilder(this, item);
    }
    OpenIDClaimsBuilder builder;
    public N and() {
      return (N) OpenIDIdentityProviderFluent.this.withClaims(builder.build());
    }
    public N endClaims() {
      return and();
    }
    
  }
  public class ClientSecretNested<N> extends SecretNameReferenceFluent<ClientSecretNested<N>> implements Nested<N>{
    ClientSecretNested(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) OpenIDIdentityProviderFluent.this.withClientSecret(builder.build());
    }
    public N endClientSecret() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.9.0-sources.jar: io/fabric8/openshift/api/model/config/v1/OpenIDIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.List;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class OpenIDIdentityProviderFluent<A extends OpenIDIdentityProviderFluent<A>> extends BaseFluent<A>{
  public OpenIDIdentityProviderFluent() {
  }
  
  public OpenIDIdentityProviderFluent(OpenIDIdentityProvider instance) {
    this.copyInstance(instance);
  }
  private ConfigMapNameReferenceBuilder ca;
  private OpenIDClaimsBuilder claims;
  private String clientID;
  private SecretNameReferenceBuilder clientSecret;
  private Map<String,String> extraAuthorizeParameters;
  private List<String> extraScopes = new ArrayList<String>();
  private String issuer;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(OpenIDIdentityProvider instance) {
    instance = (instance != null ? instance : new OpenIDIdentityProvider());
  
    if (instance != null) {
        this.withCa(instance.getCa());
        this.withClaims(instance.getClaims());
        this.withClientID(instance.getClientID());
        this.withClientSecret(instance.getClientSecret());
        this.withExtraAuthorizeParameters(instance.getExtraAuthorizeParameters());
        this.withExtraScopes(instance.getExtraScopes());
        this.withIssuer(instance.getIssuer());
        this.withCa(instance.getCa());
        this.withClaims(instance.getClaims());
        this.withClientID(instance.getClientID());
        this.withClientSecret(instance.getClientSecret());
        this.withExtraAuthorizeParameters(instance.getExtraAuthorizeParameters());
        this.withExtraScopes(instance.getExtraScopes());
        this.withIssuer(instance.getIssuer());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public ConfigMapNameReference buildCa() {
    return this.ca!=null ?this.ca.build():null;
  }
  
  public A withCa(ConfigMapNameReference ca) {
    _visitables.get("ca").remove(this.ca);
    if (ca!=null){ this.ca= new ConfigMapNameReferenceBuilder(ca); _visitables.get("ca").add(this.ca);} else { this.ca = null; _visitables.get("ca").remove(this.ca); } return (A) this;
  }
  
  public boolean hasCa() {
    return this.ca != null;
  }
  
  public A withNewCa(String name) {
    return (A)withCa(new ConfigMapNameReference(name));
  }
  
  public CaNested<A> withNewCa() {
    return new CaNested(null);
  }
  
  public CaNested<A> withNewCaLike(ConfigMapNameReference item) {
    return new CaNested(item);
  }
  
  public CaNested<A> editCa() {
    return withNewCaLike(java.util.Optional.ofNullable(buildCa()).orElse(null));
  }
  
  public CaNested<A> editOrNewCa() {
    return withNewCaLike(java.util.Optional.ofNullable(buildCa()).orElse(new ConfigMapNameReferenceBuilder().build()));
  }
  
  public CaNested<A> editOrNewCaLike(ConfigMapNameReference item) {
    return withNewCaLike(java.util.Optional.ofNullable(buildCa()).orElse(item));
  }
  
  public OpenIDClaims buildClaims() {
    return this.claims!=null ?this.claims.build():null;
  }
  
  public A withClaims(OpenIDClaims claims) {
    _visitables.get("claims").remove(this.claims);
    if (claims!=null){ this.claims= new OpenIDClaimsBuilder(claims); _visitables.get("claims").add(this.claims);} else { this.claims = null; _visitables.get("claims").remove(this.claims); } return (A) this;
  }
  
  public boolean hasClaims() {
    return this.claims != null;
  }
  
  public ClaimsNested<A> withNewClaims() {
    return new ClaimsNested(null);
  }
  
  public ClaimsNested<A> withNewClaimsLike(OpenIDClaims item) {
    return new ClaimsNested(item);
  }
  
  public ClaimsNested<A> editClaims() {
    return withNewClaimsLike(java.util.Optional.ofNullable(buildClaims()).orElse(null));
  }
  
  public ClaimsNested<A> editOrNewClaims() {
    return withNewClaimsLike(java.util.Optional.ofNullable(buildClaims()).orElse(new OpenIDClaimsBuilder().build()));
  }
  
  public ClaimsNested<A> editOrNewClaimsLike(OpenIDClaims item) {
    return withNewClaimsLike(java.util.Optional.ofNullable(buildClaims()).orElse(item));
  }
  
  public String getClientID() {
    return this.clientID;
  }
  
  public A withClientID(String clientID) {
    this.clientID=clientID; return (A) this;
  }
  
  public boolean hasClientID() {
    return this.clientID != null;
  }
  
  public SecretNameReference buildClientSecret() {
    return this.clientSecret!=null ?this.clientSecret.build():null;
  }
  
  public A withClientSecret(SecretNameReference clientSecret) {
    _visitables.get("clientSecret").remove(this.clientSecret);
    if (clientSecret!=null){ this.clientSecret= new SecretNameReferenceBuilder(clientSecret); _visitables.get("clientSecret").add(this.clientSecret);} else { this.clientSecret = null; _visitables.get("clientSecret").remove(this.clientSecret); } return (A) this;
  }
  
  public boolean hasClientSecret() {
    return this.clientSecret != null;
  }
  
  public A withNewClientSecret(String name) {
    return (A)withClientSecret(new SecretNameReference(name));
  }
  
  public ClientSecretNested<A> withNewClientSecret() {
    return new ClientSecretNested(null);
  }
  
  public ClientSecretNested<A> withNewClientSecretLike(SecretNameReference item) {
    return new ClientSecretNested(item);
  }
  
  public ClientSecretNested<A> editClientSecret() {
    return withNewClientSecretLike(java.util.Optional.ofNullable(buildClientSecret()).orElse(null));
  }
  
  public ClientSecretNested<A> editOrNewClientSecret() {
    return withNewClientSecretLike(java.util.Optional.ofNullable(buildClientSecret()).orElse(new SecretNameReferenceBuilder().build()));
  }
  
  public ClientSecretNested<A> editOrNewClientSecretLike(SecretNameReference item) {
    return withNewClientSecretLike(java.util.Optional.ofNullable(buildClientSecret()).orElse(item));
  }
  
  public A addToExtraAuthorizeParameters(String key,String value) {
    if(this.extraAuthorizeParameters == null && key != null && value != null) { this.extraAuthorizeParameters = new LinkedHashMap(); }
    if(key != null && value != null) {this.extraAuthorizeParameters.put(key, value);} return (A)this;
  }
  
  public A addToExtraAuthorizeParameters(Map<String,String> map) {
    if(this.extraAuthorizeParameters == null && map != null) { this.extraAuthorizeParameters = new LinkedHashMap(); }
    if(map != null) { this.extraAuthorizeParameters.putAll(map);} return (A)this;
  }
  
  public A removeFromExtraAuthorizeParameters(String key) {
    if(this.extraAuthorizeParameters == null) { return (A) this; }
    if(key != null && this.extraAuthorizeParameters != null) {this.extraAuthorizeParameters.remove(key);} return (A)this;
  }
  
  public A removeFromExtraAuthorizeParameters(Map<String,String> map) {
    if(this.extraAuthorizeParameters == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.extraAuthorizeParameters != null){this.extraAuthorizeParameters.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getExtraAuthorizeParameters() {
    return this.extraAuthorizeParameters;
  }
  
  public <K,V>A withExtraAuthorizeParameters(Map<String,String> extraAuthorizeParameters) {
    if (extraAuthorizeParameters == null) { this.extraAuthorizeParameters =  null;} else {this.extraAuthorizeParameters = new LinkedHashMap(extraAuthorizeParameters);} return (A) this;
  }
  
  public boolean hasExtraAuthorizeParameters() {
    return this.extraAuthorizeParameters != null;
  }
  
  public A addToExtraScopes(int index,String item) {
    if (this.extraScopes == null) {this.extraScopes = new ArrayList<String>();}
    this.extraScopes.add(index, item);
    return (A)this;
  }
  
  public A setToExtraScopes(int index,String item) {
    if (this.extraScopes == null) {this.extraScopes = new ArrayList<String>();}
    this.extraScopes.set(index, item); return (A)this;
  }
  
  public A addToExtraScopes(java.lang.String... items) {
    if (this.extraScopes == null) {this.extraScopes = new ArrayList<String>();}
    for (String item : items) {this.extraScopes.add(item);} return (A)this;
  }
  
  public A addAllToExtraScopes(Collection<String> items) {
    if (this.extraScopes == null) {this.extraScopes = new ArrayList<String>();}
    for (String item : items) {this.extraScopes.add(item);} return (A)this;
  }
  
  public A removeFromExtraScopes(java.lang.String... items) {
    if (this.extraScopes == null) return (A)this;
    for (String item : items) { this.extraScopes.remove(item);} return (A)this;
  }
  
  public A removeAllFromExtraScopes(Collection<String> items) {
    if (this.extraScopes == null) return (A)this;
    for (String item : items) { this.extraScopes.remove(item);} return (A)this;
  }
  
  public List<String> getExtraScopes() {
    return this.extraScopes;
  }
  
  public String getExtraScope(int index) {
    return this.extraScopes.get(index);
  }
  
  public String getFirstExtraScope() {
    return this.extraScopes.get(0);
  }
  
  public String getLastExtraScope() {
    return this.extraScopes.get(extraScopes.size() - 1);
  }
  
  public String getMatchingExtraScope(Predicate<String> predicate) {
    for (String item: extraScopes) { if(predicate.test(item)){ return item;} } return null;
  }
  
  public boolean hasMatchingExtraScope(Predicate<String> predicate) {
    for (String item: extraScopes) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withExtraScopes(List<String> extraScopes) {
    if (extraScopes != null) {this.extraScopes = new ArrayList(); for (String item : extraScopes){this.addToExtraScopes(item);}} else { this.extraScopes = null;} return (A) this;
  }
  
  public A withExtraScopes(java.lang.String... extraScopes) {
    if (this.extraScopes != null) {this.extraScopes.clear(); _visitables.remove("extraScopes"); }
    if (extraScopes != null) {for (String item :extraScopes){ this.addToExtraScopes(item);}} return (A) this;
  }
  
  public boolean hasExtraScopes() {
    return extraScopes != null && !extraScopes.isEmpty();
  }
  
  public String getIssuer() {
    return this.issuer;
  }
  
  public A withIssuer(String issuer) {
    this.issuer=issuer; return (A) this;
  }
  
  public boolean hasIssuer() {
    return this.issuer != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OpenIDIdentityProviderFluent that = (OpenIDIdentityProviderFluent) o;
    if (!java.util.Objects.equals(ca, that.ca)) return false;
  
    if (!java.util.Objects.equals(claims, that.claims)) return false;
  
    if (!java.util.Objects.equals(clientID, that.clientID)) return false;
  
    if (!java.util.Objects.equals(clientSecret, that.clientSecret)) return false;
  
    if (!java.util.Objects.equals(extraAuthorizeParameters, that.extraAuthorizeParameters)) return false;
  
    if (!java.util.Objects.equals(extraScopes, that.extraScopes)) return false;
  
    if (!java.util.Objects.equals(issuer, that.issuer)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(ca,  claims,  clientID,  clientSecret,  extraAuthorizeParameters,  extraScopes,  issuer,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (ca != null) { sb.append("ca:"); sb.append(ca + ","); }
    if (claims != null) { sb.append("claims:"); sb.append(claims + ","); }
    if (clientID != null) { sb.append("clientID:"); sb.append(clientID + ","); }
    if (clientSecret != null) { sb.append("clientSecret:"); sb.append(clientSecret + ","); }
    if (extraAuthorizeParameters != null && !extraAuthorizeParameters.isEmpty()) { sb.append("extraAuthorizeParameters:"); sb.append(extraAuthorizeParameters + ","); }
    if (extraScopes != null && !extraScopes.isEmpty()) { sb.append("extraScopes:"); sb.append(extraScopes + ","); }
    if (issuer != null) { sb.append("issuer:"); sb.append(issuer + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class CaNested<N> extends ConfigMapNameReferenceFluent<CaNested<N>> implements Nested<N>{
    CaNested(ConfigMapNameReference item) {
      this.builder = new ConfigMapNameReferenceBuilder(this, item);
    }
    ConfigMapNameReferenceBuilder builder;
    
    public N and() {
      return (N) OpenIDIdentityProviderFluent.this.withCa(builder.build());
    }
    
    public N endCa() {
      return and();
    }
    
  
  }
  public class ClaimsNested<N> extends OpenIDClaimsFluent<ClaimsNested<N>> implements Nested<N>{
    ClaimsNested(OpenIDClaims item) {
      this.builder = new OpenIDClaimsBuilder(this, item);
    }
    OpenIDClaimsBuilder builder;
    
    public N and() {
      return (N) OpenIDIdentityProviderFluent.this.withClaims(builder.build());
    }
    
    public N endClaims() {
      return and();
    }
    
  
  }
  public class ClientSecretNested<N> extends SecretNameReferenceFluent<ClientSecretNested<N>> implements Nested<N>{
    ClientSecretNested(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    SecretNameReferenceBuilder builder;
    
    public N and() {
      return (N) OpenIDIdentityProviderFluent.this.withClientSecret(builder.build());
    }
    
    public N endClientSecret() {
      return and();
    }
    
  
  }

}
